@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2020 Andrew Ziem
+# Copyright (C) 2008-2021 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -474,13 +474,17 @@ class System(Cleaner):
 
             def gtk_purge_items():
                 """Purge GTK items"""
-                Gtk.RecentManager().purge_items()
+                Gtk.RecentManager().get_default().purge_items()
                 yield 0
 
-            for pathname in ["~/.recently-used.xbel", "~/.local/share/recently-used.xbel"]:
-                pathname = os.path.expanduser(pathname)
-                if os.path.lexists(pathname):
-                    yield Command.Shred(pathname)
+            xbel_pathnames = [
+                    '~/.recently-used.xbel',
+                    '~/.local/share/recently-used.xbel*',
+                    '~/snap/*/*/.local/share/recently-used.xbel']
+            for path1 in xbel_pathnames:
+                for path2 in glob.iglob(os.path.expanduser(path1)):
+                    if os.path.lexists(path2):
+                        yield Command.Shred(path2)
             if HAVE_GTK:
                 # Use the Function to skip when in preview mode
                 yield Command.Function(None, gtk_purge_items, _('Recent documents list'))
@@ -551,7 +555,7 @@ class System(Cleaner):
         if HAVE_GTK and 'clipboard' == option_id:
             def clear_clipboard():
                 clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
-                clipboard.set_text(' ',1)
+                clipboard.set_text(' ', 1)
                 clipboard.clear()
                 return 0
             yield Command.Function(None, clear_clipboard, _('Clipboard'))
