@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2020 Andrew Ziem
+# Copyright (C) 2008-2021 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -80,6 +80,40 @@ def open_files_linux():
     return glob.iglob("/proc/*/fd/*")
 
 
+def get_filesystem_type(path):
+    """
+    * Get file system type from the given path
+    * return value: The tuple of (file_system_type, device_name)
+    *               @ file_system_type: vfat, ntfs, etc
+    *               @ device_name:      C://, D://, etc
+    """
+    try:
+        import psutil
+    except ImportError:
+        logger.warning('To get the file system type from the given path, you need to install psutil package')
+        return ("unknown", "none")
+
+    partitions = {}
+    for partition in psutil.disk_partitions():
+        partitions[partition.mountpoint] = (partition.fstype, partition.device)
+        
+    if path in partitions:
+        return partitions[path]
+
+    splitpath = path.split(os.sep)
+    for i in range(0, len(splitpath)-1):
+        path = os.sep.join(splitpath[:i]) + os.sep
+        if path in partitions:
+            return partitions[path]
+            
+        path = os.sep.join(splitpath[:i])
+        if path in partitions:
+            return partitions[path]
+
+    return ("unknown", "none")
+
+
+
 def open_files_lsof(run_lsof=None):
     if run_lsof is None:
         def run_lsof():
@@ -216,8 +250,8 @@ def clean_ini(path, section, parameter):
                 if key == "__name__":
                     continue
                 if (value is not None) or (parser._optcre == parser.OPTCRE):
-                    # The line bellow is the only changed line of the original function.
-                    # This is the orignal line for reference:
+                    # The line below is the only changed line of the original function.
+                    # This is the original line for reference:
                     # key = " = ".join((key, str(value).replace('\n', '\n\t')))
                     key = " = ".join((key, value.replace('\n', '\n\t')))
                 ini_file.write("%s\n" % (key))
@@ -422,7 +456,7 @@ def exe_exists(pathname):
         return exists_in_path(pathname)
 
 
-def execute_sqlite3(path, cmds, cmds_as_list=None):
+def execute_sqlite3(path, cmds):
     """Execute 'cmds' on SQLite database 'path'"""
     import sqlite3
     import contextlib
@@ -435,10 +469,7 @@ def execute_sqlite3(path, cmds, cmds_as_list=None):
         if options.get('shred'):
             cursor.execute('PRAGMA secure_delete=ON')
 
-        if cmds_as_list is None:
-            cmds_as_list = cmds.split(';')
-
-        for cmd in cmds_as_list:
+        for cmd in cmds.split(';'):
             try:
                 cursor.execute(cmd)
             except sqlite3.OperationalError as exc:
@@ -570,7 +601,7 @@ def guess_overwrite_paths():
     elif 'nt' == os.name:
         localtmp = os.path.expandvars('$TMP')
         if not os.path.exists(localtmp):
-            logger.warning(_("%TMP% does not exist: %s"), localtmp)
+            logger.warning(_("The environment variable TMP refers to a directory that does not exist: %s"), localtmp)
             localtmp = None
         from bleachbit.Windows import get_fixed_drives
         for drive in get_fixed_drives():
@@ -927,12 +958,28 @@ def wipe_path(pathname, idle=False):
                 break
             else:
                 raise
+
+        # Get the file system type from the given path
+        fstype = get_filesystem_type(pathname)
+        fstype = fstype[0]
+        logging.debug('File System:' + fstype)
+        # print(f.name) # Added by Marvin for debugging #issue 1051
         last_idle = time.time()
         # Write large blocks to quickly fill the disk.
         blanks = b'\0' * 65536
+        writtensize = 0
+        
         while True:
             try:
-                f.write(blanks)
+                if fstype != 'vfat':
+                    f.write(blanks)
+                # In the ubuntu system, the size of file should be less then 4GB. If not, there should be EFBIG error.
+                # So the maximum file size should be less than or equal to "4GB - 65536byte".
+                elif writtensize < 4 * 1024 * 1024 * 1024 - 65536:
+                    writtensize += f.write(blanks)
+                else:
+                    break
+            
             except IOError as e:
                 if e.errno == errno.ENOSPC:
                     if len(blanks) > 1:
@@ -967,7 +1014,7 @@ def wipe_path(pathname, idle=False):
         total_bytes += f.tell()
         # If no bytes were written, then quit.
         # See https://github.com/bleachbit/bleachbit/issues/502
-        if len(blanks) < 2:
+        if start_free_bytes - total_bytes < 2: # Modified by Marvin to fix the issue #1051 [12/06/2020]
             break
     # sync to disk
     sync()
