@@ -2,7 +2,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2020 Andrew Ziem
+# Copyright (C) 2008-2021 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -116,16 +116,21 @@ class Bleachbit(Gtk.Application):
     _auto_exit = False
 
     def __init__(self, uac=True, shred_paths=None, auto_exit=False):
-        if os.name == 'nt' and Windows.elevate_privileges(uac):
-            # privileges escalated in other process
-            sys.exit(0)
+
+        application_id_suffix = self._init_windows_misc(auto_exit, shred_paths, uac)
+        application_id = '{}{}'.format('org.gnome.Bleachbit', application_id_suffix)
         Gtk.Application.__init__(
-            self, application_id='org.gnome.Bleachbit', flags=Gio.ApplicationFlags.FLAGS_NONE)
+            self, application_id=application_id, flags=Gio.ApplicationFlags.FLAGS_NONE)
         GObject.threads_init()
 
+        if auto_exit:
+            # This is used for automated testing of whether the GUI can start.
+            # It is called from assert_execute_console() in windows/setup_py2exe.py
+            self._auto_exit = True        
+
         if shred_paths:
             self._shred_paths = shred_paths
-            return
+
         if os.name == 'nt':
             # clean up nonce files https://github.com/bleachbit/bleachbit/issues/858
             import atexit
@@ -139,9 +144,23 @@ class Bleachbit(Gtk.Application):
             except ImportError:
                 logger.exception(
                     _("Error loading the SQLite module: the antivirus software may be blocking it."))
-        if auto_exit:
-            # This is used for automated testing of whether the GUI can start.
-            self._auto_exit = True
+
+    def _init_windows_misc(self, auto_exit, shred_paths, uac):
+        application_id_suffix = ''
+        if os.name == 'nt':
+            if Windows.elevate_privileges(uac):
+                # privileges escalated in other process
+                sys.exit(0)
+            if portable_mode:
+                Windows.copy_fonts_in_portable_app(auto_exit)
+
+            if auto_exit and shred_paths:
+                # When we have a running application and executing the Windows
+                # context menu command we start a new process with new application_id.
+                # That is because the command line arguments of the context menu command
+                # are not passed to the already running instance.
+                application_id_suffix = 'ContextMenuShred'
+        return application_id_suffix
 
     def build_app_menu(self):
         """Build the application menu
@@ -165,7 +184,7 @@ class Bleachbit(Gtk.Application):
                    'makeChaff': self.cb_make_chaff,
                    'shredQuit': self.cb_shred_quit,
                    'preferences': self.cb_preferences_dialog,
-                   'diagnostics': self.diagnostic_dialog,
+                   'systemInformation': self.system_information_dialog,
                    'help': self.cb_help,
                    'about': self.about}
 
@@ -249,7 +268,7 @@ class Bleachbit(Gtk.Application):
 
         # Quit the application through the idle loop to allow the worker
         # to delete the files.  Use the lowest priority because the worker
-        # uses the standard priority.  Otherwise, this will quit before
+        # uses the standard priority. Otherwise, this will quit before
         # the files are deleted.
         #
         # Rebuild a minimal bleachbit.ini when quitting
@@ -284,7 +303,7 @@ class Bleachbit(Gtk.Application):
 
     def get_about_dialog(self):
         dialog = Gtk.AboutDialog(comments='Program to clean unnecessary files',
-                                 copyright='Copyright (C) 2008-2020 Andrew Ziem',
+                                 copyright='Copyright (C) 2008-2021 Andrew Ziem',
                                  program_name=APP_NAME,
                                  version=bleachbit.APP_VERSION,
                                  website=bleachbit.APP_URL,
@@ -322,13 +341,13 @@ class Bleachbit(Gtk.Application):
             bleachbit.Options.init_configuration()
         self._window.destroy()
 
-    def get_diagnostics_dialog(self):
-        """Show diagnostic information"""
+    def get_system_information_dialog(self):
+        """Show system information dialog"""
         dialog = Gtk.Dialog(_("System information"), self._window)
         dialog.set_default_size(600, 400)
         txtbuffer = Gtk.TextBuffer()
-        from bleachbit import Diagnostic
-        txt = Diagnostic.diagnostic_info()
+        from bleachbit import SystemInformation
+        txt = SystemInformation.get_system_information()
         txtbuffer.set_text(txt)
         textview = Gtk.TextView.new_with_buffer(txtbuffer)
         textview.set_editable(False)
@@ -340,8 +359,8 @@ class Bleachbit(Gtk.Application):
                            Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
         return (dialog, txt)
 
-    def diagnostic_dialog(self, _action, _param):
-        dialog, txt = self.get_diagnostics_dialog()
+    def system_information_dialog(self, _action, _param):
+        dialog, txt = self.get_system_information_dialog()
         dialog.show_all()
         while True:
             rc = dialog.run()
@@ -358,9 +377,11 @@ class Bleachbit(Gtk.Application):
                 application=self, title=APP_NAME, auto_exit=self._auto_exit)
         self._window.present()
         if self._shred_paths:
-            GLib.idle_add(GUI.shred_paths, self._window, self._shred_paths)
-            self._auto_exit = True
-        if self._auto_exit:
+            GLib.idle_add(GUI.shred_paths, self._window, self._shred_paths, priority=GObject.PRIORITY_LOW)
+            # When we shred paths and auto exit with the Windows Explorer context menu command we close the
+            # application in GUI.shred_paths, because if it is closed from here there are problems.
+            # Most probably this is something related with how GTK handles idle quit calls.
+        elif self._auto_exit:
             GLib.idle_add(self.quit,
                           priority=GObject.PRIORITY_LOW)
             print('Success')
@@ -467,7 +488,7 @@ class TreeDisplayModel:
         return self.view
 
     def set_cleaner(self, path, model, parent_window, value):
-        """Activate or deactive option of cleaner."""
+        """Activate or deactivate option of cleaner."""
         assert isinstance(value, bool)
         assert isinstance(model, Gtk.TreeStore)
         cleaner_id = None
@@ -536,7 +557,7 @@ class GUI(Gtk.ApplicationWindow):
     def __init__(self, auto_exit, *args, **kwargs):
         super(GUI, self).__init__(*args, **kwargs)
 
-        self.auto_exit = auto_exit
+        self._auto_exit = auto_exit
 
         self.set_wmclass(APP_NAME, APP_NAME)
         self.populate_window()
@@ -566,6 +587,11 @@ class GUI(Gtk.ApplicationWindow):
 
         GLib.idle_add(self.cb_refresh_operations)
 
+    def _confirm_delete(self, mention_preview, shred_settings=False):
+        if options.get("delete_confirmation"):
+            return GuiBasic.delete_confirmation_dialog(self, mention_preview, shred_settings=shred_settings)
+        return True
+
     def get_preferences_dialog(self):
         return PreferencesDialog(
             self,
@@ -578,9 +604,6 @@ class GUI(Gtk.ApplicationWindow):
         When shredding_settings=True:
         If user confirms to delete, then returns True.  If user aborts, returns
         False.
-
-        When quit_when_done=True:
-        Always returns False to remove function from the idle queue.
         """
         # create a temporary cleaner object
         backends['_gui'] = Cleaner.create_simple_cleaner(paths)
@@ -589,10 +612,15 @@ class GUI(Gtk.ApplicationWindow):
         operations = {'_gui': ['files']}
         self.preview_or_run_operations(False, operations)
 
-        if GuiBasic.delete_confirmation_dialog(self, mention_preview=False, shred_settings=shred_settings):
+        if self._confirm_delete(False, shred_settings):
             # delete
             self.preview_or_run_operations(True, operations)
-            return True
+            if shred_settings:
+                return True
+
+        if self._auto_exit:
+            GLib.idle_add(self.close,
+                              priority=GObject.PRIORITY_LOW)
 
         # user aborted
         return False
@@ -688,10 +716,8 @@ class GUI(Gtk.ApplicationWindow):
         # Disable delete confirmation message.
         # if the option is selected under preference.
 
-        if options.get("delete_confirmation"):
-            if not GuiBasic.delete_confirmation_dialog(self, True):
-                return
-        self.preview_or_run_operations(True)
+        if self._confirm_delete(True):
+            self.preview_or_run_operations(True)
 
     def preview_or_run_operations(self, really_delete, operations=None):
         """Preview operations or run operations (delete files)"""
@@ -754,13 +780,17 @@ class GUI(Gtk.ApplicationWindow):
         self.view = display.make_view(
             mdl, self, self.context_menu_event)
         self.view.get_selection().connect("changed", self.on_selection_changed)
-        scrolled_window.add(self.view)
+        padding_box = Gtk.Box()
+        padding_box.add(self.view)
+        scrollbar_width = scrolled_window.get_vscrollbar().get_preferred_width()[1]
+        padding_box.set_margin_right(scrollbar_width) # avoid conflict with scrollbar
+        scrolled_window.add(padding_box)
         return scrolled_window
 
     def cb_refresh_operations(self):
         """Callback to refresh the list of cleaners"""
         # Is this the first time in this session?
-        if not hasattr(self, 'recognized_cleanerml') and not self.auto_exit:
+        if not hasattr(self, 'recognized_cleanerml') and not self._auto_exit:
             from bleachbit import RecognizeCleanerML
             RecognizeCleanerML.RecognizeCleanerML()
             self.recognized_cleanerml = True
@@ -781,7 +811,7 @@ class GUI(Gtk.ApplicationWindow):
         self.view.expand_all()
 
         # Check for online updates.
-        if not self.auto_exit and \
+        if not self._auto_exit and \
             bleachbit.online_update_notification_enabled and \
             options.get("check_online_updates") and \
                 not hasattr(self, 'checked_for_updates'):
@@ -790,7 +820,7 @@ class GUI(Gtk.ApplicationWindow):
 
         # Show information for first start.
         # (The first start flag is set also for each new version.)
-        if options.get("first_start") and not self.auto_exit:
+        if options.get("first_start") and not self._auto_exit:
             if os.name == 'posix':
                 self.append_text(
                     _('Access the application menu by clicking the hamburger icon on the title bar.'))
@@ -835,7 +865,7 @@ class GUI(Gtk.ApplicationWindow):
             return
 
         # delete
-        if GuiBasic.delete_confirmation_dialog(self, mention_preview=False):
+        if self._confirm_delete(False):
             self.preview_or_run_operations(True, operations)
             return
 
@@ -856,7 +886,7 @@ class GUI(Gtk.ApplicationWindow):
         # context menu applies only to children, not parents
         if len(path) != 2:
             return False
-        # find the seleted option
+        # find the selected option
         model = treeview.get_model()
         option_id = model[path][2]
         cleaner_id = model[path[0]][2]
@@ -1051,6 +1081,8 @@ class GUI(Gtk.ApplicationWindow):
 
     def on_show(self, widget):
         # restore window position, size and state
+        if not options.get('remember_geometry'):
+            return
         if options.has_option("window_x") and options.has_option("window_y") and \
            options.has_option("window_width") and options.has_option("window_height"):
             r = Gdk.Rectangle()
