@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2020 Andrew Ziem
+# Copyright (C) 2008-2021 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -34,7 +34,7 @@ logger = logging.getLogger(__name__)
 def __get_chrome_history(path, fn='History'):
     """Get Google Chrome or Chromium history version.  'path' is name of any file in same directory"""
     path_history = os.path.join(os.path.dirname(path), fn)
-    ver = get_sqlite(
+    ver = get_sqlite_int(
         path_history, 'select value from meta where key="version"')[0]
     assert ver > 1
     return ver
@@ -73,8 +73,8 @@ def __sqlite_table_exists(pathname, table):
     return ret
 
 
-def get_sqlite(path, sql, parameters=None, element_type=int):
-    """Run SQL on database in 'path' and return the elements"""
+def get_sqlite_int(path, sql, parameters=None):
+    """Run SQL on database in 'path' and return the integers"""
     ids = []
     import sqlite3
     conn = sqlite3.connect(path)
@@ -84,7 +84,7 @@ def get_sqlite(path, sql, parameters=None, element_type=int):
     else:
         cursor.execute(sql)
     for row in cursor:
-        ids.append(element_type(row[0]))
+        ids.append(int(row[0]))
     cursor.close()
     conn.close()
     return ids
@@ -300,7 +300,7 @@ def delete_mozilla_url_history(path):
 
     # delete any orphaned input history
     input_suffix = "where place_id not in (select distinct id from moz_places)"
-    cols = ('input', )
+    cols = ('input',)
     cmds += __shred_sqlite_char_columns('moz_inputhistory', cols, input_suffix)
 
     # delete the whole moz_hosts table
@@ -318,32 +318,28 @@ def delete_mozilla_url_history(path):
 def delete_mozilla_favicons(path):
     """Delete favorites icon in Mozilla places.favicons only if they are not bookmarks (Firefox 3 and family)"""
 
-    # Use list here because some urls contain semicolon and this
-    # way we aviod wrongly splitting by semicolon in execute_sqlite3.
-    cmds = []
+    cmds = ""
 
-    # collect bookmarked urls
     places_path = os.path.join(os.path.dirname(path), 'places.sqlite')
-    bookmark_urls_cmd = (
-        "select url from moz_places where id in (select distinct fk from moz_bookmarks where fk is not null)"
-    )
-    bookmark_urls = get_sqlite(places_path, bookmark_urls_cmd, element_type=str)
-    bookmark_urls = ",".join(["'{}'".format(url.replace("'", "''")) for url in bookmark_urls])
+    cmds += "attach database \"%s\" as places;" % places_path
 
     # delete all not bookmarked icon urls
-    urls_where = "where (page_url not in ({}))".format(bookmark_urls)
-    cmds.append(__shred_sqlite_char_columns('moz_pages_w_icons', ('page_url',), urls_where))
+    urls_where = (
+        "where page_url not in (select url from places.moz_places where id in "
+        "(select distinct fk from places.moz_bookmarks where fk is not null))"
+    )
+    cmds += __shred_sqlite_char_columns('moz_pages_w_icons', ('page_url',), urls_where)
 
     # delete all not bookmarked icons to pages mapping
-    mapping_where = "where (page_id not in (select id from moz_pages_w_icons))"
-    cmds.append(__shred_sqlite_char_columns('moz_icons_to_pages', where=mapping_where))
+    mapping_where = "where page_id not in (select id from moz_pages_w_icons)"
+    cmds += __shred_sqlite_char_columns('moz_icons_to_pages', where=mapping_where)
 
     # delete all not bookmarked icons
     icons_where = "where (id not in (select icon_id from moz_icons_to_pages))"
-    cols = ('icon_url','data')
-    cmds.append(__shred_sqlite_char_columns('moz_icons', cols, where=icons_where))
+    cols = ('icon_url', 'data')
+    cmds += __shred_sqlite_char_columns('moz_icons', cols, where=icons_where)
 
-    FileUtilities.execute_sqlite3(path, None, cmds_as_list=cmds)
+    FileUtilities.execute_sqlite3(path, cmds)
 
 
 def delete_ooo_history(path):
@@ -371,7 +367,7 @@ def get_chrome_bookmark_ids(history_path):
     urls = get_chrome_bookmark_urls(bookmark_path)
     ids = []
     for url in urls:
-        ids += get_sqlite(
+        ids += get_sqlite_int(
             history_path, 'select id from urls where url=?', (url,))
     return ids
 
