@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2020 Andrew Ziem
+# Copyright (C) 2008-2021 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -43,6 +43,9 @@ except AttributeError:
     Pattern = re._pattern_type
 
 
+JOURNALD_REGEX = r'^Vacuuming done, freed ([\d.]+[BKMGT]?) of archived journals (on disk|from [\w/]+).$'
+
+
 class LocaleCleanerPath:
     """This represents a path with either a specific folder name or a folder name pattern.
     It also may contain several compiled regex patterns for localization items (folders or files)
@@ -406,7 +409,7 @@ class Locales:
 
 
 def __is_broken_xdg_desktop_application(config, desktop_pathname):
-    """Returns boolean whether application deskop entry file is broken"""
+    """Returns boolean whether application desktop entry file is broken"""
     if not config.has_option('Desktop Entry', 'Exec'):
         logger.info(
             "is_broken_xdg_menu: missing required option 'Exec': '%s'", desktop_pathname)
@@ -605,9 +608,8 @@ def run_cleaner_cmd(cmd, args, freed_space_regex=r'[\d.]+[kMGTE]?B?', error_line
 
 def journald_clean():
     """Clean the system journals"""
-    freed_space_regex = '^Vacuuming done, freed ([\d.]+[KMGT]?) of archived journals on disk.$'
     try:
-        return run_cleaner_cmd('journalctl', ['--vacuum-size=1'], freed_space_regex)
+        return run_cleaner_cmd('journalctl', ['--vacuum-size=1'], JOURNALD_REGEX)
     except subprocess.CalledProcessError as e:
         raise RuntimeError("Error calling '%s':\n%s" %
                            (' '.join(e.cmd), e.output))
