@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2020 Andrew Ziem
+# Copyright (C) 2008-2021 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -44,6 +44,7 @@ import glob
 import logging
 import os
 import sys
+import shutil
 
 from decimal import Decimal
 
@@ -65,6 +66,11 @@ if 'win32' == sys.platform:
 logger = logging.getLogger(__name__)
 
 
+_GTK_FONTS_FOLDER = r'share\fonts'
+_SEGOEUI = 'segoeui.ttf'
+_TAHOMA = 'tahoma.ttf'
+
+
 def browse_file(_, title):
     """Ask the user to select a single file.  Return full path"""
     try:
@@ -208,25 +214,36 @@ def delete_registry_key(parent_key, really_delete):
 
 def delete_updates():
     """Returns commands for deleting Windows Updates files"""
-    windir = os.path.expandvars('$windir')
+    windir = os.path.expandvars('%windir%')
     dirs = glob.glob(os.path.join(windir, '$NtUninstallKB*'))
-    dirs += [os.path.expandvars('$windir\\SoftwareDistribution\\Download')]
-    dirs += [os.path.expandvars('$windir\\ie7updates')]
-    dirs += [os.path.expandvars('$windir\\ie8updates')]
+    dirs += [os.path.expandvars(r'%windir%\SoftwareDistribution')]
+    dirs += [os.path.expandvars(r'%windir%\SoftwareDistribution.old')]
+    dirs += [os.path.expandvars(r'%windir%\SoftwareDistribution.bak')]
+    dirs += [os.path.expandvars(r'%windir%\ie7updates')]
+    dirs += [os.path.expandvars(r'%windir%\ie8updates')]
+    dirs += [os.path.expandvars(r'%windir%\system32\catroot2')]
     if not dirs:
         # if nothing to delete, then also do not restart service
         return
 
-    import win32serviceutil
-    wu_running = win32serviceutil.QueryServiceStatus('wuauserv')[1] == 4
+    args = []
 
-    args = ['net', 'stop', 'wuauserv']
-
-    def wu_service():
+    def run_wu_service():
         General.run_external(args)
         return 0
-    if wu_running:
-        yield Command.Function(None, wu_service, " ".join(args))
+
+    services = {}
+    all_services = ('wuauserv', 'cryptsvc', 'bits', 'msiserver')
+    for service in all_services:
+        import win32serviceutil
+        services[service] = win32serviceutil.QueryServiceStatus(service)[
+            1] == 4
+        logger.debug('Windows service {} has current state: {}'.format(
+            service, services[service]))
+
+        if services[service]:
+            args = ['net', 'stop', service]
+            yield Command.Function(None, run_wu_service, " ".join(args))
 
     for path1 in dirs:
         for path2 in FileUtilities.children_in_directory(path1, True):
@@ -234,9 +251,10 @@ def delete_updates():
         if os.path.exists(path1):
             yield Command.Delete(path1)
 
-    args = ['net', 'start', 'wuauserv']
-    if wu_running:
-        yield Command.Function(None, wu_service, " ".join(args))
+    for this_service in all_services:
+        if services[this_service]:
+            args = ['net', 'start', this_service]
+            yield Command.Function(None, run_wu_service, " ".join(args))
 
 
 def detect_registry_key(parent_key):
@@ -393,6 +411,7 @@ def get_known_folder_path(folder_name):
     class FOLDERID:
         LocalAppDataLow = UUID(
             '{A520A1A4-1780-4FF6-BD18-167343C5AF16}')
+        Fonts = UUID('{FD228CB7-AE11-4AE3-864C-16F3910AB8FE}')
 
     class UserHandle:
         current = wintypes.HANDLE(0)
@@ -568,3 +587,20 @@ def split_registry_key(full_key):
     if k1 not in hive_map:
         raise RuntimeError("Invalid Windows registry hive '%s'" % k1)
     return hive_map[k1], k2
+
+
+def copy_fonts_in_portable_app(auto_exit):
+    # Fix #1040: copy only two fonts in order to escape huge default fontconfig caching.
+    # We do this here only for portable app as for the installed app we do it through the installer.
+
+    if (
+        hasattr(sys, 'frozen') and
+        bleachbit.portable_mode  and
+        not auto_exit
+    ):
+        windows_fonts_folder = get_known_folder_path('Fonts')
+        os.makedirs(_GTK_FONTS_FOLDER, exist_ok=True)
+        for font in [_SEGOEUI, _TAHOMA]:
+            gtk_font_path = os.path.join(_GTK_FONTS_FOLDER, font)
+            if not os.path.exists(gtk_font_path):
+                shutil.copy(os.path.join(windows_fonts_folder, font), gtk_font_path)
