@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2020 Andrew Ziem
+# Copyright (C) 2008-2021 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,7 @@ Perform the preview or delete operations
 
 from bleachbit import DeepScan, FileUtilities
 from bleachbit.Cleaner import backends
-from bleachbit import _, ungettext
+from bleachbit import _, ngettext
 
 import logging
 import math
@@ -194,6 +194,7 @@ class Worker:
             msg = _("Please wait.  Wiping free disk space.")
             self.ui.append_text(
                 _('Wiping free disk space erases remnants of files that were deleted without shredding. It does not free up space.'))
+            self.ui.append_text('\n')
         elif 'memory' == option_id:
             msg = _("Please wait.  Cleaning %s.") % _("Memory")
         else:
@@ -213,7 +214,7 @@ class Worker:
                     self.ui.update_progress_bar(percent_done)
                     if isinstance(eta_seconds, int):
                         eta_mins = math.ceil(eta_seconds / 60)
-                        msg2 = ungettext("About %d minute remaining.",
+                        msg2 = ngettext("About %d minute remaining.",
                                          "About %d minutes remaining.", eta_mins) \
                             % eta_mins
                         self.ui.update_progress_bar(msg + ' ' + msg2)
