@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2020 Andrew Ziem
+# Copyright (C) 2008-2021 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -32,7 +32,7 @@ import platform
 from bleachbit import Log
 from configparser import RawConfigParser, NoOptionError, SafeConfigParser
 
-APP_VERSION = "4.2.0"
+APP_VERSION = "4.4.0"
 APP_NAME = "BleachBit"
 APP_URL = "https://www.bleachbit.org"
 
@@ -102,6 +102,12 @@ elif 'nt' == os.name:
     else:
         # installed mode
         options_dir = os.path.expandvars(r"${APPDATA}\BleachBit")
+
+try:
+    options_dir = os.environ['BLEACHBIT_TEST_OPTIONS_DIR']
+except KeyError:
+    pass
+        
 options_file = os.path.join(options_dir, "bleachbit.ini")
 
 # check whether the application is running from the source tree
@@ -231,10 +237,10 @@ except:
     logger.exception('error binding text domain')
 
 try:
-    ungettext = t.ungettext
+    ngettext = t.ngettext
 except:
-    def ungettext(singular, plural, n):
-        """Dummy replacement for Unicode, plural gettext"""
+    def ngettext(singular, plural, n):
+        """Dummy replacement for plural gettext"""
         if 1 == n:
             return singular
         return plural
@@ -252,6 +258,7 @@ except:
 
 # pgettext(msgctxt, msgid) from gettext is not supported in Python as of January 2017
 # http://bugs.python.org/issue2504
+# This issue was fixed in Python 3.8, but we need to support older versions.
 # Meanwhile we get official support, we have to simulate it.
 # See http://www.gnu.org/software/gettext/manual/gettext.html#Ambiguities for
 # more information about pgettext.
@@ -308,4 +315,4 @@ if 'posix' == os.name:
 if 'posix' == os.name:
     fs_scan_re_flags = 0 # should be re.IGNORECASE on macOS
 else:
-    fs_scan_re_flags = re.IGNORECASE
\ No newline at end of file
+    fs_scan_re_flags = re.IGNORECASE
